antares.apps.client.migrations package
======================================

Submodules
----------

antares.apps.client.migrations.0001\_initial module
---------------------------------------------------

.. automodule:: antares.apps.client.migrations.0001_initial
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.migrations.0002\_auto\_20180624\_1759 module
----------------------------------------------------------------

.. automodule:: antares.apps.client.migrations.0002_auto_20180624_1759
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.migrations.0003\_auto\_20190629\_1936 module
----------------------------------------------------------------

.. automodule:: antares.apps.client.migrations.0003_auto_20190629_1936
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.client.migrations
   :members:
   :undoc-members:
   :show-inheritance:
